pub struct RangeImageConfig {
pub width: usize,
pub height: usize,
pub fov_up_deg: f32,
pub fov_down_deg: f32,
}Expand description
Configuration for range_image.
Fields
width: usizeImage width in pixels (azimuth resolution).
height: usizeImage height in pixels (one row per laser beam).
fov_up_deg: f32Upper bound of the vertical field of view, in degrees.
fov_down_deg: f32Lower bound of the vertical field of view, in degrees (usually negative).
Implementations